@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: FLEXI-STREAMS; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/flexi-streams/specials.lisp,v 1.13 2006/11/14 20:53:16 edi Exp $
+;;; $Header: /usr/local/cvsrep/flexi-streams/specials.lisp,v 1.23 2007/03/22 21:40:11 edi Exp $
 
-;;; Copyright (c) 2005-2006, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2005-2007, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -71,6 +71,7 @@
     (:latin0 . :iso-8859-15)
     (:latin-10 . :iso-8859-16)
     (:latin10 . :iso-8859-16)
+    (:codepage . :code-page)
     #+(and :lispworks :win32)
     (win32:code-page . :code-page))
   "An alist which mapes alternative names for external formats to
@@ -114,25 +115,53 @@ long forms.")
   #+:win32 :crlf
   #-:win32 :lf
   "The end-of-line style used by external formats if none is
-explicitely given.  Depends on the OS the code is compiled on.")
+explicitly given.  Depends on the OS the code is compiled on.")
 
 (defvar *default-little-endian*
   #+:little-endian t
   #-:little-endian nil
   "Whether external formats are little-endian by default
-\(i.e. unless explicitely specified).  Depends on the platform
+\(i.e. unless explicitly specified).  Depends on the platform
 the code is compiled on.")
 
-(defvar *use-replacement-char* nil
-  "Whether reading an unknown octet for an 8-bit encoding should
-return the replacement character (65533) instead of signalling an
-error.")
-
 (defvar *substitution-char* nil
   "If this value is not NIL, it should be a character which is used
 \(as if by a USE-VALUE restart) whenever during reading an error of
 type FLEXI-STREAM-ENCODING-ERROR would have been signaled otherwise.")
 
+(defun invert-table (table)
+  "`Inverts' an array which maps octets to character codes to a
+hash tables which maps character codes to octets."
+  (let ((hash (make-hash-table)))
+    (loop for octet from 0
+          for char-code across table
+          unless (= char-code 65533)
+          do (setf (gethash char-code hash) octet))
+    hash))
+
+(defvar +iso-8859-hashes+
+  (loop for (name . table) in +iso-8859-tables+
+        collect (cons name (invert-table table)))
+  "An alist which maps names for ISO-8859 encodings to hash
+tables which map character codes to the corresponding octets.")
+
+(defvar +code-page-hashes+
+  (loop for (id . table) in +code-page-tables+
+        collect (cons id (invert-table table)))
+  "An alist which maps IDs of Windows code pages to hash tables
+which map character codes to the corresponding octets.")
+
+(defvar +ascii-hash+ (invert-table +ascii-table+)
+  "A hash table which maps US-ASCII character codes to the
+corresponding octets.")
+
+(defvar +koi8-r-hash+ (invert-table +koi8-r-table+)
+  "A hash table which maps KOI8-R character codes to the
+corresponding octets.")
+
+(defconstant +buffer-size+ 8192
+  "Size of buffers used for internal purposes.")
+
 ;; stuff for Nikodemus Siivola's HYPERDOC
 ;; see <http://common-lisp.net/project/hyperdoc/>
 ;; and <http://www.cliki.net/hyperdoc>
